@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vector-instances
 version: 3.3.1
-id: vector-instances-3.3.1-defbdcf4d1ffa7a1e6ebdf8243634c01
-key: vecto_ATBzJ1h6rApJ5wl3FzOLKo
+id: vector-instances-3.3.1-02e9d5a5e0f0cb8c3532624a3303c400
+key: vecto_29T3XlNRWcbE9UFYgo4Lv6
 license: BSD3
 maintainer: ekmett@gmail.com
 homepage: http://github.com/ekmett/vector-instances
@@ -17,14 +17,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-instances-3.3.1
-hs-libraries: HSvector-instances-3.3.1-ATBzJ1h6rApJ5wl3FzOLKo
+hs-libraries: HSvector-instances-3.3.1-29T3XlNRWcbE9UFYgo4Lv6
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-a91321d086a2de4a04a44d60c347669e
-    keys-3.11-138176c47b9b6dd0d393596bbcd2f16d
-    pointed-5-28a4d891bf88c5f993d8a907568960a6
-    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
+    comonad-5-e98e7adc8875accf64a86529d9aeae51
+    keys-3.11-c0312e613ec912c390e00fde3001f005
+    pointed-5-43ce6d13385073054689e0a07f00abbe
+    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
 haddock-html: /usr/share/doc/haskell-vector-instances/html
